# Expected types for each column
# Some of these columns are ints but represent coded categories and
# are converted to their coded labels and returned as str
# See ONS_CIS_CATEGORY_COLUMNS
ONS_CIS_COLUMN_MAPPINGS = {
    "age_at_visit": "int",
    "contact_any_covid": "bool",
    "contact_any_covid_dayssinceg": "int",
    "contact_face_covering": "int",
    "country": "int",
    "covid_admitted": "bool",
    "covid_date": "date",
    "covid_nhs_contact": "bool",
    "covid_test_blood": "bool",
    "covid_test_blood_neg_last_date": "date",
    "covid_test_blood_pos_first_date": "date",
    "covid_test_blood_result": "int",
    "covid_test_swab": "bool",
    "covid_test_swab_neg_last_date": "date",
    "covid_test_swab_pos_first_date": "date",
    "covid_test_swab_result": "int",
    "covid_think_havehad": "bool",
    "ct_mean": "float",
    "dataset": "int",
    "ethnicity": "int",
    "geography_code": "str",
    "geography_name": "str",
    "gor9d": "int",
    "health_care_clean": "bool",
    "health_conditions": "bool",
    "health_conditions_impact": "int",
    "hhsize": "int",
    "patient_facing_clean": "int",
    "received_ox_date": "date",
    "result_combined": "int",
    "result_mk": "int",
    "result_mk_date": "date",
    "result_tdi": "int",
    "samples_taken_date": "date",
    "school_year": "int",
    "self_isolating": "bool",
    "self_isolating_v1": "int",
    "sex": "int",
    "smoke_ever_regularly": "bool",
    "smoke_now_cigar": "bool",
    "smoke_now_cigarettes": "bool",
    "smoke_now_pipe": "bool",
    "smoke_now_vape": "bool",
    "SOC_occupation": "str",
    "sympt_covid_abdominal_pain": "bool",
    "sympt_covid_any": "bool",
    "sympt_covid_cough": "bool",
    "sympt_covid_diarrhoea": "bool",
    "sympt_covid_fatigue_weakness": "bool",
    "sympt_covid_fever": "bool",
    "sympt_covid_headache": "bool",
    "sympt_covid_loss_of_smell": "bool",
    "sympt_covid_loss_of_taste": "bool",
    "sympt_covid_muscle_ache_myalgia": "bool",
    "sympt_covid_nausea_vomiting": "bool",
    "sympt_covid_shortness_of_breath": "bool",
    "sympt_covid_sore_throat": "bool",
    "sympt_now_abdominal_pain": "bool",
    "sympt_now_any": "bool",
    "sympt_now_cough": "bool",
    "sympt_now_date": "date",
    "sympt_now_diarrhoea": "bool",
    "sympt_now_fatigue_weakness": "bool",
    "sympt_now_fever": "bool",
    "sympt_now_headache": "bool",
    "sympt_now_loss_of_smell": "bool",
    "sympt_now_loss_of_taste": "bool",
    "sympt_now_muscle_ache_myalgia": "bool",
    "sympt_now_nausea_vomiting": "bool",
    "sympt_now_shortness_of_breath": "bool",
    "sympt_now_sore_throat": "bool",
    "tenure_group": "int",
    "think_have_covid_sympt_now": "bool",
    "travel_abroad": "bool",
    "travel_abroad_date": "date",
    "visit_date": "date",
    "pseudo_visit_id": "bytes",
    "work_direct_contact_patients_etc": "bool",
    "work_location": "int",
    "work_outside_home_days": "int",
    "work_sector": "int",
    "work_social_distancing": "int",
    "work_status": "int",
    "work_status_clean": "int",
    "work_status_v1": "int",
    "work_travel": "int",
}


# ONS_CIS has a lot of columns that can be returned
# Some columns are ints, but represented category values
# These need to be cast to varchar in the db.
COVID_TEST_RESULTS_CODES = {
    0: "Any tests negative, but none positive",
    1: "One or more positive test(s)",
    2: "Waiting for all results",
    9: "All Tests failed",
}


RESULTS_CODES = {
    0: "Negative",
    1: "Positive",
    7: "Rejected",
    8: "Inconclusive",
    9: "Void",
    10: "Insufficient sample",
    11: "Could not process",
    12: "Unassayed",
}


HH_SIZE_CODES = {1: "1", 2: "2", 3: "3", 4: "4", 5: "5+"}


ONS_CIS_CATEGORY_COLUMNS = {
    "contact_any_covid_dayssinceg": {
        1: "0-14",
        2: "15-28",
        3: "29-60",
        4: "61-90",
        5: "91+",
    },
    "contact_face_covering": {
        0: "No",
        1: "Yes, at work/school only",
        2: "Yes, in other situations only",
        3: "Yes, usually both Work/school/other",
        4: "My face is already covered",
    },
    "country": {0: "England", 1: "Wales", 2: "NI", 3: "Scotland"},
    "covid_test_blood_result": COVID_TEST_RESULTS_CODES,
    "covid_test_swab_result": COVID_TEST_RESULTS_CODES,
    "dataset": {
        0: "Voyager 1 original",
        1: "Voyager 1 upgrade",
        2: "Voyager 2",
    },
    "ethnicity": {
        1: "White-British",
        2: "White-Irish",
        3: "White-Gypsy or Irish Traveller",
        4: "Any other white background",
        5: "Mixed-White & Black Caribbean",
        6: "Mixed-White & Black African",
        7: "Mixed-White & Asian",
        8: "Any other Mixed background",
        9: "Asian or Asian British-Indian",
        10: "Asian or Asian British-Pakistani",
        11: "Asian or Asian British-Bangladeshi",
        12: "Asian or Asian British-Chinese",
        13: "Any other Asian background",
        14: "Black,Caribbean,African-African",
        15: "Black,Caribbean,Afro-Caribbean",
        16: "Any other Black background",
        17: "Other ethnic group-Arab",
        18: "Any other ethnic group",
    },
    "gor9d": {
        1: "E12000001",
        2: "E12000002",
        3: "E12000003",
        4: "E12000004",
        5: "E12000005",
        6: "E12000006",
        7: "E12000007",
        8: "E12000008",
        9: "E12000009",
        10: "N99999999",
        11: "S99999999",
        12: "W99999999",
    },
    "health_conditions_impact": {
        0: "Not at all",
        1: "Yes, a little",
        2: "Yes, a lot",
    },
    "hhsize": HH_SIZE_CODES,
    "patient_facing_clean": {
        0: "No",
        1: "Yes",
        2: "Not working in health care",
    },
    "result_combined": RESULTS_CODES,
    "result_mk": RESULTS_CODES,
    "result_tdi": RESULTS_CODES,
    "self_isolating_v1": {
        0: "No",
        1: "Yes, you have/have had symptoms",
        2: "Yes, someone you live with had symptoms",
        3: "Yes, for other reasons (e.g. going into hospital, quarantining)",
    },
    "sex": {1: "Male", 2: "Female"},
    "surge_flag": {
        0: "No",
        1: "boost1",
        2: "boost2",
    },
    "tenure_group": {
        1: "Owner, missing",
        2: "Mortgage",
        3: "Rent, squatting etc",
    },
    "work_location": {
        -9: "<=15y",
        -8: ">=75y",
        1: "Working from home",
        2: "Working somewhere else (not your home)",
        3: "Both (from home and somewhere else)",
        4: "Not applicable, not currently working",
    },
    "work_sector": {
        1: "Teaching and education",
        2: "Health care",
        3: "Social care",
        4: "Transport (incl. storage, logistic)",
        5: "Retail sector (incl. wholesale)",
        6: "Hospitality (e.g. hotel, restaurant)",
        7: "Food production, agriculture, farming",
        8: "Personal services (e.g. hairdressers)",
        9: "Information technology and communication",
        10: "Financial services incl. insurance",
        11: "Manufacturing or construction",
        12: "Civil service or Local Government",
        13: "Armed forces",
        14: "Arts,Entertainment or Recreation",
        15: "Other occupation sector",
        99: "NA(Not currently working)",
    },
    "work_social_distancing": {
        1: "Easy to maintain 2m",
        2: "Relatively easy to maintain 2m",
        3: "Difficult to maintain 2m, but can be 1m",
        4: "Very difficult to be more than 1m away",
        9: "N/A (not working/in education etc)",
    },
    "work_status": {
        1: "Employed",
        2: "Self-employed",
        3: "Furloughed (temporarily not working)",
        4: "Not working (unemployed, retired, long-term sick etc.)",
        5: "Student",
    },
    "work_status_clean": {
        0: "Not working",
        1: "Working",
        2: "Student",
    },
    "work_status_v1": {
        1: "Employed and currently working",
        2: "Employed and currently not working",
        3: "Self-employed and currently working",
        4: "Self-employed and currently not working",
        5: "Looking for paid work and able to start",
        6: "Not working and not looking for work",
        7: "Retired",
        8: "Child under 5y not attending child care",
        9: "Child under 5y attending child care",
        10: "5y and older in full-time education",
    },
    "work_travel": {
        1: "Underground, metro, light rail, tram",
        2: "Train",
        3: "Bus, minibus, coach",
        4: "Motorbike, scooter or moped",
        5: "Car or van",
        6: "Taxi/minicab",
        7: "Bicycle",
        8: "On foot",
        9: "Other method",
        99: "N/A (not working/in education etc)",
    },
}
